==> react-lds-8.7.0.tgz: package/es/components/Modal/Modal.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.object.set-prototype-of";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import FocusTrap from 'focus-trap-react';
import ModalHeader from './ModalHeader';
import { getContentId, getTitleId } from './utils';

var Modal =
/*#__PURE__*/
function (_Component) {
  _inherits(Modal, _Component);

  function Modal(props) {
    var _this;

    _classCallCheck(this, Modal);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Modal).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "onClose", function (evt) {
      evt.stopPropagation();
      var onClose = _this.props.onClose;

      if (onClose) {
        onClose(evt);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "onKeyUp", function (evt) {
      var key = evt.key;

      if (key === 'Escape') {
        evt.stopPropagation();

        _this.onClose(evt);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "setRef", function (ref) {
      _this.focusTrapOptions.fallbackFocus = ref;
    });

    _defineProperty(_assertThisInitialized(_this), "cloneWithProps", function (child) {
      var _this$props = _this.props,
          id = _this$props.id,
          onClose = _this$props.onClose;
      if (!child) return child; // Passing props to both children, need to ignore onClose in body and vice versa
      // react-hot-loader wraps a ProxyFacade, checking child.type is not really feasible
      // https://github.com/gaearon/react-hot-loader/issues/938

      return React.cloneElement(child, {
        id: getContentId(id),
        onClose: onClose ? _this.onClose : null
      });
    });

    _this.focusTrapOptions = {
      escapeDeactivates: false,
      fallbackFocus: null
    };
    return _this;
  }

  _createClass(Modal, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          className = _this$props2.className,
          id = _this$props2.id,
          open = _this$props2.open,
          onClose = _this$props2.onClose,
          prompt = _this$props2.prompt,
          size = _this$props2.size,
          tagline = _this$props2.tagline,
          title = _this$props2.title,
          transitionStyle = _this$props2.transitionStyle,
          rest = _objectWithoutProperties(_this$props2, ["children", "className", "id", "open", "onClose", "prompt", "size", "tagline", "title", "transitionStyle"]);

      var titleId = title ? getTitleId(id) : null;
      var contentId = getContentId(id);
      var sldsClasses = cx('slds-modal', _defineProperty({}, "slds-".concat(transitionStyle), open), _defineProperty({}, "slds-modal_".concat(size), !!size), {
        'slds-modal_prompt': !!prompt
      }, className);
      return React.createElement(FocusTrap, {
        active: open,
        focusTrapOptions: this.focusTrapOptions,
        onKeyUp: onClose ? this.onKeyUp : null
      }, React.createElement("section", _extends({}, rest, {
        className: sldsClasses,
        ref: this.setRef,
        role: prompt ? 'alertdialog' : 'dialog',
        tabIndex: -1,
        "aria-modal": "true",
        "aria-describedby": contentId,
        "aria-labelledby": titleId
      }), React.createElement("div", {
        className: "slds-modal__container"
      }, React.createElement(ModalHeader, {
        id: titleId,
        onClose: onClose ? this.onClose : null,
        theme: prompt,
        tagline: tagline,
        title: title
      }), React.Children.map(children, this.cloneWithProps))), React.createElement("div", {
        className: cx(['slds-backdrop', {
          'slds-backdrop_open': open
        }])
      }));
    }
  }]);

  return Modal;
}(Component);

Modal.defaultProps = {
  className: null,
  open: false,
  prompt: null,
  onClose: null,
  size: null,
  tagline: null,
  title: null,
  transitionStyle: 'fade-in-open'
};
Modal.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Sets the animation style when the modal open.
   * Can be one of: 'fade-in-open', 'slide-up-saving', 'slide-up-open', 'slide-down-cancel'
   */
  transitionStyle: PropTypes.oneOf(['fade-in-open', 'slide-up-saving', 'slide-up-open', 'slide-down-cancel']),

  /**
   * ModalContent and optionally a ModalFooter
   */
  children: PropTypes.node.isRequired,

  /**
   * className that will be merged
   */
  className: PropTypes.string,

  /**
   * Callback that is triggered when `x` is clicked or `esc` is pressed. Will be passed to a `ModalFooter` if present
   */
  onClose: PropTypes.func,

  /**
   * id that is used to link Moal aria-tags to each other
   */
  id: PropTypes.string.isRequired,

  /**
   * Opens the Modal and renders the backdrop
   */
  open: PropTypes.bool,

  /**
   * Size of modal. Can be `medium` or `large`
   */
  size: PropTypes.oneOf(['medium', 'large']),

  /**
   * Tagline. Can be a string or an element
   */
  tagline: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /**
   * Title
   */
  title: PropTypes.string,

  /**
   * (PRIVATE) used by Prompt component
   */
  prompt: PropTypes.string
} : {};
export default Modal;

==> react-lds-9.0.2.tgz: package/es/components/Modal/Modal.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.array.map";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import FocusTrap from 'focus-trap-react';
import ModalHeader from './ModalHeader';
import { getContentId, getTitleId } from './utils';

var Modal =
/*#__PURE__*/
function (_Component) {
  _inherits(Modal, _Component);

  function Modal(props) {
    var _this;

    _classCallCheck(this, Modal);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Modal).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "onClose", function (evt) {
      evt.stopPropagation();
      var onClose = _this.props.onClose;

      if (onClose) {
        onClose(evt);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "onKeyUp", function (evt) {
      var key = evt.key;

      if (key === 'Escape') {
        evt.stopPropagation();

        _this.onClose(evt);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "setRef", function (ref) {
      _this.focusTrapOptions.fallbackFocus = ref;
    });

    _defineProperty(_assertThisInitialized(_this), "cloneWithProps", function (child) {
      var _this$props = _this.props,
          id = _this$props.id,
          onClose = _this$props.onClose;
      if (!child) return child; // Passing props to both children, need to ignore onClose in body and vice versa
      // react-hot-loader wraps a ProxyFacade, checking child.type is not really feasible
      // https://github.com/gaearon/react-hot-loader/issues/938

      return React.cloneElement(child, {
        id: getContentId(id),
        onClose: onClose ? _this.onClose : null
      });
    });

    _this.focusTrapOptions = {
      escapeDeactivates: false,
      fallbackFocus: null
    };
    return _this;
  }

  _createClass(Modal, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          className = _this$props2.className,
          id = _this$props2.id,
          open = _this$props2.open,
          onClose = _this$props2.onClose,
          prompt = _this$props2.prompt,
          size = _this$props2.size,
          tagline = _this$props2.tagline,
          title = _this$props2.title,
          transitionStyle = _this$props2.transitionStyle,
          rest = _objectWithoutProperties(_this$props2, ["children", "className", "id", "open", "onClose", "prompt", "size", "tagline", "title", "transitionStyle"]);

      var titleId = title ? getTitleId(id) : null;
      var contentId = getContentId(id);
      var sldsClasses = cx('slds-modal', _defineProperty({}, "slds-".concat(transitionStyle), open), _defineProperty({}, "slds-modal_".concat(size), !!size), {
        'slds-modal_prompt': !!prompt
      }, className);
      return React.createElement(FocusTrap, {
        active: open,
        focusTrapOptions: this.focusTrapOptions,
        onKeyUp: onClose ? this.onKeyUp : null
      }, React.createElement("section", _extends({}, rest, {
        className: sldsClasses,
        ref: this.setRef,
        role: prompt ? 'alertdialog' : 'dialog',
        tabIndex: -1,
        "aria-modal": "true",
        "aria-describedby": contentId,
        "aria-labelledby": titleId
      }), React.createElement("div", {
        className: "slds-modal__container"
      }, React.createElement(ModalHeader, {
        id: titleId,
        onClose: onClose ? this.onClose : null,
        theme: prompt,
        tagline: tagline,
        title: title
      }), React.Children.map(children, this.cloneWithProps))), React.createElement("div", {
        className: cx(['slds-backdrop', {
          'slds-backdrop_open': open
        }])
      }));
    }
  }]);

  return Modal;
}(Component);

Modal.defaultProps = {
  className: null,
  open: false,
  prompt: null,
  onClose: null,
  size: null,
  tagline: null,
  title: null,
  transitionStyle: 'fade-in-open'
};
Modal.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Sets the animation style when the modal open.
   * Can be one of: 'fade-in-open', 'slide-up-saving', 'slide-up-open', 'slide-down-cancel'
   */
  transitionStyle: PropTypes.oneOf(['fade-in-open', 'slide-up-saving', 'slide-up-open', 'slide-down-cancel']),

  /**
   * ModalContent and optionally a ModalFooter
   */
  children: PropTypes.node.isRequired,

  /**
   * className that will be merged
   */
  className: PropTypes.string,

  /**
   * Callback that is triggered when `x` is clicked or `esc` is pressed. Will be passed to a `ModalFooter` if present
   */
  onClose: PropTypes.func,

  /**
   * id that is used to link Moal aria-tags to each other
   */
  id: PropTypes.string.isRequired,

  /**
   * Opens the Modal and renders the backdrop
   */
  open: PropTypes.bool,

  /**
   * Size of modal. Can be `medium` or `large`
   */
  size: PropTypes.oneOf(['medium', 'large']),

  /**
   * Tagline. Can be a string or an element
   */
  tagline: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),

  /**
   * Title
   */
  title: PropTypes.string,

  /**
   * (PRIVATE) used by Prompt component
   */
  prompt: PropTypes.string
} : {};
export default Modal;
